@@ -4,14 +4,11 @@ from typing import Optional
 import streamlit as st
 import streamlit.components.v1 as components
 
-# Tell streamlit that there is a component called portfolio_carousel,
-# and that the code to display that component is in the "frontend" folder
 frontend_dir = (Path(__file__).parent / "frontend").absolute()
 _component_func = components.declare_component(
 	"portfolio_carousel", path=str(frontend_dir)
 )
 
-# Create the python function that will be called
 def portfolio_carousel(
     title: str,
     subtitle: str,
@@ -29,13 +26,13 @@ def portfolio_carousel(
     )
 
     return component_value
-
+# print("teste")
 
 def main():
     title = "Work"     
     subtitle =  '''Check my commercioal and non commercial projects.
                If you have any questions feel free to ask me for more information'''
-    cards = [["images/zenk.jpg", "ZENK project", "Web Scraping | RPA | Data Anlysis", "A formação da memória requer a expressão gênica induzida pela atividade neuronal. Esta resposta inclui uma série de genes dependentes de atividade tidos como mediadores das mudanças necessárias para a consolidação e manutenção da memória."],
+    cards = [["images/zenk.jpg", "ZENK project", "Web Scraping | RPA | Data Anlysis", "A formação da memória requer a expressão gênica induzida A formação da memória requer a expressão gênica induzida A formação da memória requer a expressão gênica induzida A formação da memória requer a expressão gênica induzida A formação da memória requer a expressão gênica induzida pela atividade neuronal. Esta resposta inclui uma série de genes dependentes de atividade tidos como mediadores das mudanças necessárias para a consolidação e manutenção da memória."],
              ["images/B2B.jpg", "Prospecção de Clientes B2B", "Google API | Python | Streamlit", "Aplicação para prospectar potenciais clientes B2B no Rio Grande do Norte utilizando uma API da Google chamada Places."],
              ["images/tracking.jpg", "Bird Tracking", "Data Processing | Data Visualization", "Aplicação para processar dados de coordenadas e gerar visualizações em mapa de calor."]]
             
